@@ -1,20 +1,28 @@
 import logging
 
+import sys
+import os
+
 from ..util import properties
 from ..backend import KeyringBackend
 from ..errors import (InitError, PasswordDeleteError,
-    ExceptionRaisedContext)
+                      ExceptionRaisedContext)
 
 try:
     import secretstorage
     import secretstorage.exceptions as exceptions
 except ImportError:
     pass
+except AttributeError:
+    # See https://github.com/jaraco/keyring/issues/296
+    pass
 
 log = logging.getLogger(__name__)
 
+
 class Keyring(KeyringBackend):
     """Secret Service Keyring"""
+    appid = os.path.basename(sys.argv[0]) or 'Python keyring library'
 
     @properties.ClassProperty
     @classmethod
@@ -40,14 +48,15 @@ class Keyring(KeyringBackend):
         bus = secretstorage.dbus_init()
         try:
             if hasattr(self, 'preferred_collection'):
-                collection = secretstorage.Collection(bus, self.preferred_collection)
+                collection = secretstorage.Collection(
+                    bus, self.preferred_collection)
             else:
                 collection = secretstorage.get_default_collection(bus)
         except exceptions.SecretStorageException as e:
             raise InitError("Failed to create the collection: %s." % e)
         if collection.is_locked():
             collection.unlock()
-            if collection.is_locked(): # User dismissed the prompt
+            if collection.is_locked():  # User dismissed the prompt
                 raise InitError("Failed to unlock the collection!")
         return collection
 
@@ -68,10 +77,10 @@ class Keyring(KeyringBackend):
         """
         collection = self.get_preferred_collection()
         attributes = {
-            "application": "python-keyring",
+            "application": self.appid,
             "service": service,
             "username": username
-            }
+        }
         label = "Password for '%s' on '%s'" % (username, service)
         collection.create_item(label, attributes, password, replace=True)
 
